A function to estimate the risk of recurrence using cancer registry disease-specific grouped survival data.
recurrisk.group(data, data.cansurv, stagevar, stage.dist.value, adj.r = 1)The SEER*Stat cause-specific or relative group survival data frame returned by function read.seerstat.
The data frame including parameter estimation and covariance matrix for the mixture cure survival model from Cansurv CSV format output. It also contains the information on strata and covariates.
The stage variable containing the distant stage from SEER*Stat data.
The numeric value of distant stage.
The adjustment factor used to adjust the registry-based survival curves for sensitivity analysis. The default value is 1.
A data frame containing the following items.
The parametric survival distribution among those not cured specified in CanSurv.
The cure fraction estimated from the mixture cure survival model.
The estimated scale parameter of the survival distribution for those not cured.
The estimated shape parameter of the survival distribution for those not cured.
The exponential hazard of the time from recurrence to cancer death.
The survival estimated from the mixture cure survival model.
The estimated survival for the non-cured fraction.
The median survival time for the non-cured fraction.
The numerical estimated survival to recurrence (recurrence-free survival) for the non-cured fraction.
The numerical estimated survival to recurrence.
1-G_numerical, the numerical estimated cumulative incidence of recurrence which is the probability of progressing to cancer recurrence.
The analytical estimated survival to recurrence (recurrence-free survival) for the non-cured fraction.
The analytical estimated survival to recurrence.
1-G_analytical, the analytical estimated cumulative incidence of recurrence.
The standard error of CI_analytical.
The observed survival from SEER*Stat.
The observed survival for distant stage from SEER*Stat.
# NOT RUN {
data("data.group")
data("data.cansurv")
stagevar<-"SEER_historic_stage_LRD"
stage.dist.value<-2
adj.r<-1.5
out<-recurrisk.group(data.group, data.cansurv, stagevar, stage.dist.value, adj.r)
# }
Run the code above in your browser using DataLab